# Class: Host&#95;driver

UNSUPPORTED. A multi&#45;version driver on a host

## Fields for class: Host&#95;driver

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`active_variant`    |`Driver_variant ref`|_RO/runtime_   |Currently active variant of this driver, if any, or Null.|
|`description`       |`string`            |_RO/runtime_   |Description of the driver               |
|`friendly_name`     |`string`            |_RO/runtime_   |Descriptive name, not used for identification|
|`host`              |`host ref`          |_RO/constructor_|Host where this driver is installed     |
|`info`              |`string`            |_RO/runtime_   |Information about the driver            |
|`name`              |`string`            |_RO/runtime_   |Name identifying the driver uniquely    |
|`selected_variant`  |`Driver_variant ref`|_RO/runtime_   |Variant &#40;if any&#41; selected to become active after reboot. Or Null|
|`type`              |`string`            |_RO/runtime_   |Device type this driver supports, like network or storage|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`variants`          |`Driver_variant ref set`|_RO/runtime_   |Variants of this driver available for selection|

## RPCs associated with class: Host&#95;driver

### RPC name: deselect

_Overview:_

UNSUPPORTED. Deselect the currently active variant of this driver after reboot. No action will be taken if no variant is currently active.

_Signature:_

```
void deselect (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |Driver to become inactive &#40;after reboot&#41;.|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;active&#95;variant

_Overview:_

Get the active&#95;variant field of the given Host&#95;driver.

_Signature:_

```
Driver_variant ref get_active_variant (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant ref`

value of the field

### RPC name: get&#95;all

_Overview:_

Return a list of all the Host&#95;drivers known to the system.

_Signature:_

```
Host_driver ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Host_driver ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Host&#95;driver references to Host&#95;driver records for all Host&#95;drivers known to the system.

_Signature:_

```
(Host_driver ref -> Host_driver record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Host_driver ref -> Host_driver record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Host&#95;driver instance with the specified UUID.

_Signature:_

```
Host_driver ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Host_driver ref`

reference to the object

### RPC name: get&#95;description

_Overview:_

Get the description field of the given Host&#95;driver.

_Signature:_

```
string get_description (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;friendly&#95;name

_Overview:_

Get the friendly&#95;name field of the given Host&#95;driver.

_Signature:_

```
string get_friendly_name (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given Host&#95;driver.

_Signature:_

```
host ref get_host (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;info

_Overview:_

Get the info field of the given Host&#95;driver.

_Signature:_

```
string get_info (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name

_Overview:_

Get the name field of the given Host&#95;driver.

_Signature:_

```
string get_name (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Host&#95;driver.

_Signature:_

```
Host_driver record get_record (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Host_driver record`

all fields from the object

### RPC name: get&#95;selected&#95;variant

_Overview:_

Get the selected&#95;variant field of the given Host&#95;driver.

_Signature:_

```
Driver_variant ref get_selected_variant (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant ref`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given Host&#95;driver.

_Signature:_

```
string get_type (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Host&#95;driver.

_Signature:_

```
string get_uuid (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;variants

_Overview:_

Get the variants field of the given Host&#95;driver.

_Signature:_

```
Driver_variant ref set get_variants (session ref session_ref, Host_driver ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant ref set`

value of the field

### RPC name: rescan

_Overview:_

UNSUPPORTED. Re&#45;scan a host's drivers and update information about them. This is mostly  for trouble shooting.

_Signature:_

```
void rescan (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |Update driver information of this host. |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: select

_Overview:_

UNSUPPORTED. Select a variant of the driver to become active after reboot or immediately if currently no version is active

_Signature:_

```
void select (session ref session_ref, Host_driver ref self, Driver_variant ref variant)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Host_driver ref`             |`self`                        |Driver to become active &#40;after reboot&#41;.|
|`Driver_variant ref`          |`variant`                     |Driver version to become active &#40;after reboot&#41;.|

_Minimum Role:_ pool-admin

_Return Type:_ `void`
