# Class: host&#95;metrics

The metrics associated with a host

## Fields for class: host&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`last_updated`      |`datetime`          |_RO/runtime_   |Time at which this information was last updated|
|`live`              |`bool`              |_RO/runtime_   |Pool master thinks this host is live    |
|`memory_free`       |`int`               |_RO/runtime_   |**Removed.** Free host memory &#40;bytes&#41;        |
|`memory_total`      |`int`               |_RO/runtime_   |Total host memory &#40;bytes&#41;       |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: host&#95;metrics

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_ref, host_metrics ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the host&#95;metrics instances known to the system.

_Signature:_

```
host_metrics ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host&#95;metrics references to host&#95;metrics records for all host&#95;metrics instances known to the system.

_Signature:_

```
(host_metrics ref -> host_metrics record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(host_metrics ref -> host_metrics record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host&#95;metrics instance with the specified UUID.

_Signature:_

```
host_metrics ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref`

reference to the object

### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given host&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;live

_Overview:_

Get the live field of the given host&#95;metrics.

_Signature:_

```
bool get_live (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;memory&#95;free

**This message is removed.**

_Overview:_

Get the memory/free field of the given host&#95;metrics.

_Signature:_

```
int get_memory_free (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;memory&#95;total

_Overview:_

Get the memory/total field of the given host&#95;metrics.

_Signature:_

```
int get_memory_total (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host&#95;metrics.

_Signature:_

```
host_metrics record get_record (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_ref, host_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, host_metrics ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_ref, host_metrics ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host_metrics ref`            |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
